@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999 Alfredo K. Kojima
+ * Copyright (c) 1999-2005 Alfredo K. Kojima, Alban Hertroys
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -18,20 +18,20 @@
  * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
- * $Id: dacallback.c,v 1.2 2002/10/04 17:24:46 dalroi Exp $
+ * $Id: dacallback.c,v 1.4 2005/04/17 11:52:31 dalroi Exp $
  */
 
 #include "dockapp.h"
+#include "daargs.h"
 
-extern DACallbacks	d_callbacks;
-extern int		d_timeout;
+extern struct DAContext *_daContext;
 
 void
 DASetCallbacks(DACallbacks *callbacks)
 {
     long	mask = 0;
     
-    d_callbacks = *callbacks;
+    _daContext->callbacks = *callbacks;
 
     if (callbacks->destroy)
 	mask |= StructureNotifyMask;
@@ -53,6 +53,6 @@ DASetCallbacks(DACallbacks *callbacks)
 void
 DASetTimeout(int milliseconds)
 {
-    d_timeout = milliseconds;
+    _daContext->timeOut = milliseconds;
 }
 
