@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999 Alfredo K. Kojima
+ * Copyright (c) 1999-2005 Alfredo K. Kojima, Alban Hertroys
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -18,12 +18,14 @@
  * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
- * $Id: dacolor.c,v 1.1.1.1 2002/09/05 17:59:11 dalroi Exp $
+ * $Id: dacolor.c,v 1.4 2005/04/20 18:05:04 dalroi Exp $
  */
 
 #include "dockapp.h"
+#include "daargs.h"
+#include "dautil.h"
 
-extern char	*progName;
+extern struct DAContext *_daContext;
 
 unsigned long
 DAGetColor(char *colorName)
@@ -33,10 +35,10 @@ DAGetColor(char *colorName)
     if (!XParseColor(DADisplay,
 		DefaultColormap(DADisplay, DefaultScreen(DADisplay)),
 		colorName, &color))
-	printf("%s: could not parse color %s\n", progName, colorName), exit(1);
+	DAError("could not parse color %s", colorName);
     
     if (!XAllocColor(DADisplay, DefaultColormap(DADisplay, DefaultScreen(DADisplay)), &color)) {
-	printf("%s: could not allocate color %s. Using black\n", progName, colorName);
+	DAWarning("could not allocate color %s. Using black instead", colorName);
 	return BlackPixel(DADisplay, DefaultScreen(DADisplay));
     }
     
