@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999 Alfredo K. Kojima
+ * Copyright (c) 1999-2003 Alfredo K. Kojima, Alban Hertroys
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -18,21 +18,16 @@
  * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
- * $Id: damain.c,v 1.8 2003/02/10 12:35:03 dalroi Exp $
+ * $Id: damain.c,v 1.16 2005/04/20 18:05:04 dalroi Exp $
  */
 
 #include "dockapp.h"
+#include "daargs.h"
 #include "dautil.h"
 
-
 #define MIN(a, b)	(a < b ? a : b)
 
-
-char		*progName = NULL;
-int		d_width, d_height;
-int		d_windowed = 0;
-int		d_timeout = 0;
-DACallbacks	d_callbacks = {NULL, NULL, NULL, NULL, NULL, NULL, NULL};
+struct DAContext *_daContext;
 
 DARect		DANoRect = {0, 0, 0, 0};
 Display		*DADisplay = NULL;
@@ -53,7 +48,7 @@ DAOpenDisplay(char *display, int argc, char **argv)
     /* Open Connection to X Server */
     DADisplay = XOpenDisplay(display);
     if (!DADisplay) {
-	printf("%s: could not open display %s!\n", progName,
+	printf("%s: could not open display %s!\n", _daContext->programName,
 		XDisplayName(display));
 	exit(EXIT_FAILURE);
     }
@@ -70,8 +65,8 @@ DAProposeIconSize(unsigned width, unsigned height)
     XIconSize		*iconSizes;
     int			nrSizes = 0;
 
-    d_width	= width;
-    d_height	= height;
+    _daContext->width	= width;
+    _daContext->height	= height;
 
     /* Get the nearest allowed icon size if the WM specifies such */
     iconSizes = XAllocIconSize();
@@ -110,8 +105,8 @@ DAProposeIconSize(unsigned width, unsigned height)
 	    h = MIN(h1, iconSizes[i].height_inc - h1);
 
     	    if ((w * h < da) || (da == -1)) {
-		d_width  = width  + w;
-		d_height = height + h;
+		_daContext->width  = width  + w;
+		_daContext->height = height + h;
 		da = w * h;
 	    }
 	}
@@ -122,9 +117,9 @@ DAProposeIconSize(unsigned width, unsigned height)
 	DAPreferredIconSizes.height = max_h;
 
 	if (da == -1) {	/* requested size is out of bounds */
-	    warn("Requested icon-size (%d x %d) is out of the range "
+	    DAWarning("Requested icon-size (%d x %d) is out of the range "
 		    "allowed by the window manager\n",
-		    d_width, d_height);
+		    _daContext->width, _daContext->height);
 	}
     }
     XFree(iconSizes);
@@ -140,14 +135,14 @@ DACreateIcon(char *name, unsigned width, unsigned height, int argc, char **argv)
     unsigned long	valueMask;
     char		*resourceValue;
 
-    d_width  = width;
-    d_height = height;
+    _daContext->width  = width;
+    _daContext->height = height;
 
     /* Create Windows */
     DALeader = XCreateSimpleWindow(DADisplay, DefaultRootWindow(DADisplay),
 	    0, 0, width, height, 0, 0, 0);
 
-    if (! d_windowed) {
+    if (! _daContext->windowed) {
 	DAIcon = XCreateSimpleWindow(DADisplay, DefaultRootWindow(DADisplay),
 		0, 0, width, height, 0, 0, 0);
 	DAWindow = DAIcon;
@@ -158,7 +153,8 @@ DACreateIcon(char *name, unsigned width, unsigned height, int argc, char **argv)
 
     /* Set ClassHint */
     if (!(classHint = XAllocClassHint()))
-	printf("%s: can't allocate memory for class hints!\n", progName), exit(1);
+	printf("%s: can't allocate memory for class hints!\n",
+		_daContext->programName), exit(1);
     classHint->res_class = RES_CLASSNAME;
     classHint->res_name = name;
 
@@ -167,12 +163,13 @@ DACreateIcon(char *name, unsigned width, unsigned height, int argc, char **argv)
 
     /* Set WMHints */
     if (!(wmHints = XAllocWMHints()))
-	printf("%s: can't allocate memory for wm hints!\n", progName), exit(1);
+	printf("%s: can't allocate memory for wm hints!\n",
+		_daContext->programName), exit(1);
 
     wmHints->flags = WindowGroupHint;
     wmHints->window_group = DALeader;
 
-    if (!d_windowed) {
+    if (!_daContext->windowed) {
     	wmHints->flags |= IconWindowHint|StateHint;
 	wmHints->icon_window = DAIcon;
     	wmHints->initial_state = WithdrawnState;
@@ -225,7 +222,7 @@ DAShowWindow(Window window)
 
 {
     XMapRaised(DADisplay, window);
-    if ((window == DALeader) && !d_windowed) {
+    if ((window == DALeader) && !_daContext->windowed) {
 	XMapSubwindows(DADisplay, DAIcon);
     } else {
 	XMapSubwindows(DADisplay, window);
@@ -235,136 +232,11 @@ DAShowWindow(Window window)
 }
 
 
-static void
-printHelp(char *prog, char *description, DAProgramOption *options, int count)
-{
-    int j, defCount;
-    DAProgramOption defaultOptions[] = {
-	{"-h", "--help", "shows this help text and exit", DONone, False, {NULL}},
-	{"-v", "--version",  "shows program version and exit", DONone, False, {NULL}},
-	{"-w", "--windowed", "runs the application in windowed mode", DONone, False, {NULL}}
-    };
-   
-    printf("Usage: %s [OPTIONS]\n", prog);
-    if (description)
-	puts(description);
-
-    defCount	= sizeof(defaultOptions)/sizeof(DAProgramOption);
-
-    for (j = 0; j < count + defCount; j++)
-    {
-	char blank[30];
-	int c;
-	int i;
-
-	if (j >= count) {
-	    options = defaultOptions;
-	    i = j - count;
-	}
-	else
-	    i = j;
-
-	if (options[i].shortForm && options[i].longForm)
-	    c = printf("  %s, %s", options[i].shortForm, options[i].longForm);
-	else if (options[i].shortForm)
-	    c = printf("  %s", options[i].shortForm);
-	else if (options[i].longForm)
-	    c = printf("  %s", options[i].longForm);
-	else
-	    continue;
-
-	if (options[i].type != DONone) {
-	    switch (options[i].type) {
-		case DOInteger:
-		    c += printf(" <integer>");
-		    break;
-		case DOString:
-		    c += printf(" <string>");
-		    break;
-		case DONatural:
-		    c += printf(" <number>");
-		    break;
-	    }
-	}
-
-	memset(blank, ' ', 30);
-	if (c > 29)
-	    c = 1;
-	blank[30-c] = 0;
-	printf("%s %s\n", blank, options[i].description);
-    }
-}
-
-
+/* Deprecated */
 void
-DAParseArguments(int argc, char **argv, DAProgramOption *options,
-	int count, char *programDescription, char *versionDescription)
+DAInitialize(char *display, char *name, unsigned width, unsigned height,
+	int argc, char **argv)
 {
-    int i, j;
-    int found = 0;
-
-    progName	= argv[0];
-
-    for (i = 1; i < argc; i++) {
-	if (strcmp(argv[i], "-h") == 0 || strcmp(argv[i], "--help") == 0)
-	    printHelp(argv[0], programDescription, options, count), exit(0);
-	if (strcmp(argv[i], "-v") == 0 || strcmp(argv[i], "--version") == 0)
-	    puts(versionDescription), exit(0);
-	if (strcmp(argv[i], "-w") == 0 || strcmp(argv[i], "--windowed") == 0) {
-	    d_windowed = 1;
-	    continue;
-	}
-
-	found = 0;
-	for (j = 0; j < count; j++) {
-	    if ((options[j].shortForm && strcmp(options[j].shortForm, argv[i]) == 0) ||
-		    (options[j].longForm && strcmp(options[j].longForm, argv[i]) == 0)) {
-		found = 1;
-		
-		options[j].used = True;
-		
-		if (options[j].type == DONone)
-		    break;
-		
-		i++;
-		if (i >= argc)
-		    printf("%s: missing argument for option '%s'\n", argv[0], argv[i-1]), exit(1);
-		
-		switch (options[j].type) {
-		    case DOInteger:
-			{
-			    int integer;
-			    
-			    if (sscanf(argv[i], "%i", &integer) != 1)
-				printf("%s: error parsing argument for option %s\n",
-					argv[0], argv[i-1]), exit(1);
-					*options[j].value.integer = integer;
-			}
-			break;
-		    case DONatural:
-			{
-			    int integer;
-			    
-			    if (sscanf(argv[i], "%i", &integer) != 1)
-				printf("%s: error oarsing argument for option %s\n",
-					argv[0], argv[i-1]), exit(1);
-					if (integer < 0)
-					    printf("%s: argument %s must be >= 0\n",
-						    argv[0], argv[i-1]), exit(1);
-						    *options[j].value.integer = integer;
-			}
-			break;
-		    case DOString:
-			*options[j].value.string = argv[i];
-			break;
-		}
-		break;
-	    }
-	}
-	if (!found) {
-	    printf("%s: unrecognized option '%s'\n", argv[0], argv[i]);
-	    printHelp(argv[0], programDescription, options, count), exit(1);
-	}
-    }
+    DAOpenDisplay(display, argc, argv);
+    DACreateIcon(name, width, height, argc, argv);
 }
-
