@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 Alban G. Hertroys
+ * Copyright (c) 2003-2005 Alban G. Hertroys
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -18,8 +18,8 @@
  * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  *
- * $Id: dautil.h,v 1.1 2003/01/26 16:59:01 dalroi Exp $
+ * $Id: dautil.h,v 1.4 2005/04/20 18:05:04 dalroi Exp $
  */
 
-void warn(const char *warning, ...);
+void debug(const char *message, ...);
 
